Actions
=======

.. automodule:: smonad.actions
   :members:
   :show-inheritance:

   .. add these functions explicitly as they are not functions per se, so they
      will not be documented automatically

   .. autofunction:: ftry(failure_handler, success_handler=identity)
   .. autofunction:: first(sequence, default=Nothing, predicate=None)
   .. autofunction:: tryout(*functions)
